InputSync

Enum InputSync 

pub enum InputSync {
    Disabled = 0,
    NegativeEdge = 1,
    PositiveEdge = 2,
}
Available on crate feature unstable only.
Configures the clock edge used in one of the two input synchronization stages to synchronize the GPIO input signal to the system clock, reducing metastability.

See InputConfig::with_input_sync_stage1 and InputConfig::with_input_sync_stage2.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Variants



Disabled = 0

Stage is disabled; the signal passes through without latching (hardware default).



NegativeEdge = 1

Stage latches on the falling edge of the GPIO clock.



PositiveEdge = 2

Stage latches on the rising edge of the GPIO clock.